@@ -202,12 +202,17 @@ sub process_command {
 	$command="command_$command";
 	my $ret=join(' ', $this->$command(@params));
 	debug developer => "--> $ret";
+	if ($ret=~/\n/) {
+		debug developer => 'Warning: return value is multiline, and would break the debconf protocol. Truncating to first line.';
+		$ret=~s/\n.*//;
+		debug developer => "--> $ret";
+	}
 	return $ret;
 }
 
 =item finish
 
-Waits for the child process (f any) to finish so its return code can be
+Waits for the child process (if any) to finish so its return code can be
 examined.  The return code is stored in the exitcode field of the object.
 It also marks all questions that were shown as seen.
 
@@ -224,7 +229,10 @@ sub finish {
 	$SIG{PIPE} = sub {};
 	
 	foreach (@{$this->seen}) {
-		$_->flag('seen', 'true');
+		# Try to get the question again, because it's possible it
+		# was shown, and then unregistered.
+		my $q=Debconf::Question->get($_->name);
+		$_->flag('seen', 'true') if $q;
 	}
 	$this->seen([]);
 	
@@ -251,6 +259,8 @@ sub command_input {
 		return $codes{syntaxerror}, "\"$priority\" is not a valid priority";
 	}
 
+	$question->priority($priority);
+	
 	# Figure out if the question should be displayed to the user or
 	# not.
 	my $visible=1;
@@ -261,8 +271,8 @@ sub command_input {
 	# Don't show items that are unimportant.
 	$visible='' unless high_enough($priority);
 
-	# Unless showold is set, don't re-show already seen questions.
-	$visible='' if Debconf::Config->showold() eq 'false' &&
+	# Don't re-show already seen questions, unless reconfiguring.
+	$visible='' if ! Debconf::Config->reshow &&
 	               $question->flag('seen') eq 'true';
 
 	my $element;
@@ -374,6 +384,26 @@ sub command_title {
 	return $codes{success};
 }
 
+=item command_settitle
+
+Uses the short description of a question as the title, with automatic i18n.
+
+=cut
+
+sub command_settitle {
+	my $this=shift;
+	
+	return $codes{syntaxerror}, "Incorrect number of arguments" if @_ != 1;
+	my $question_name=shift;
+	
+	my $question=Debconf::Question->get($question_name) ||
+		return $codes{badparams}, "\"$question_name\" doesn't exist";
+
+	$this->frontend->title($question->description);
+	
+	return $codes{success};
+}
+
 =item beginblock, endblock
 
 These are just stubs to be overridden by other modules.
@@ -516,15 +546,16 @@ sub command_register {
 	my $template=shift;
 	my $name=shift;
 	
-	if (! Debconf::Question->get($template)) {
+	my $tempobj = Debconf::Question->get($template);
+	if (! $tempobj) {
 		return $codes{badparams}, "No such template, \"$template\"";
 	}
 	my $question=Debconf::Question->get($name) || 
-	             Debconf::Question->new($name, $this->owner);
+	             Debconf::Question->new($name, $this->owner, $tempobj->type);
 	if (! $question) {
 		return $codes{internalerror}, "Internal error making question";
 	}
-	if (! defined $question->addowner($this->owner)) {
+	if (! defined $question->addowner($this->owner, $tempobj->type)) {
 		return $codes{internalerror}, "Internal error adding owner";
 	}
 	if (! $question->template($template)) {
@@ -718,7 +749,7 @@ sub DESTROY {
 
 =head1 AUTHOR
 
-Joey Hess <joey@kitenet.net>
+Joey Hess <joeyh@debian.org>
 
 =cut
 
