@@ -34,8 +34,15 @@ sub copy {
 	debug "db $this->{name}" => "copying $item from $src->{name} to $dest->{name}";
 	
 	# First copy the owners, which makes sure $dest has the item.
-	foreach my $owner ($src->owners($item)) {
-		$dest->addowner($item, $owner);
+	my @owners=$src->owners($item);
+	if (! @owners) {
+		@owners=("unknwon");
+	}
+	foreach my $owner (@owners) {
+		my $template = Debconf::Template->get($src->getfield($item, 'template'));
+		my $type;
+		$type = $template->type if $template;
+		$dest->addowner($item, $owner, $type);
 	}
 	# Now the fields.
 	foreach my $field ($src->fields($item)) {
@@ -53,7 +60,7 @@ sub copy {
 
 =head1 AUTHOR
 
-Joey Hess <joey@kitenet.net>
+Joey Hess <joeyh@debian.org>
 
 =cut
 
