@@ -81,7 +81,7 @@ sub AUTOLOAD {
 
 =head1 AUTHOR
 
-Joey Hess <joey@kitenet.net>
+Joey Hess <joeyh@debian.org>
 
 =cut
 
