@@ -8,8 +8,10 @@ Debconf::Element::Gnome::Select - drop down select box widget
 
 package Debconf::Element::Gnome::Select;
 use strict;
-use Gtk;
-use Gnome;
+use Gtk2;
+use Gnome2;
+use utf8;
+use Debconf::Encoding qw(to_Unicode);
 use base qw(Debconf::Element::Gnome Debconf::Element::Select);
 
 =head1 DESCRIPTION
@@ -22,11 +24,11 @@ sub init {
 	my $this=shift;
 
 	my $default=$this->translate_default;
-	my @choices=$this->question->choices_split;
+	my @choices= map { to_Unicode($_) } $this->question->choices_split;
 
 	$this->SUPER::init(@_);
 
-	$this->widget(Gtk::Combo->new);
+	$this->widget(Gtk2::Combo->new);
 	$this->widget->show;
 
 	$this->widget->set_popdown_strings(@choices);
@@ -34,7 +36,7 @@ sub init {
 	$this->widget->entry->set_editable(0);
 
 	if (defined($default) and length($default) != 0) {
-		$this->widget->entry->set_text($default);
+		$this->widget->entry->set_text(to_Unicode($default));
 	}
 	else {
 		$this->widget->entry->set_text($choices[0]);
@@ -42,6 +44,7 @@ sub init {
 
 	$this->adddescription;
 	$this->addwidget($this->widget);
+	$this->tip( $this->widget->entry );
 	$this->addhelp;
 }
 
@@ -54,9 +57,8 @@ locale.
 
 sub value {
 	my $this=shift;
-	my @choices=$this->question->choices_split;
 
-	return $this->translate_to_C($this->widget->entry->get_chars(0, -1));
+	return $this->translate_to_C_uni($this->widget->entry->get_chars(0, -1));
 }
 
 =back
@@ -64,6 +66,7 @@ sub value {
 =head1 AUTHOR
 
 Eric Gillespie <epg@debian.org>
+Gustavo Noronha Silva <kov@debian.org>
 
 =cut
 
